/* A Bison parser, made by GNU Bison 3.0.4.  */

/* Bison interface for Yacc-like parsers in C

   Copyright (C) 1984, 1989-1990, 2000-2015 Free Software Foundation, Inc.

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.

   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

#ifndef YY_SHELL_PARSER_SHELLQUERY_TAB_H_INCLUDED
# define YY_SHELL_PARSER_SHELLQUERY_TAB_H_INCLUDED
/* Debug traces.  */
#ifndef SHELL_DEBUG
# if defined YYDEBUG
#if YYDEBUG
#   define SHELL_DEBUG 1
#  else
#   define SHELL_DEBUG 0
#  endif
# else /* ! defined YYDEBUG */
#  define SHELL_DEBUG 1
# endif /* ! defined YYDEBUG */
#endif  /* ! defined SHELL_DEBUG */
#if SHELL_DEBUG
extern int shell_debug;
#endif

/* Token type.  */
#ifndef SHELL_TOKENTYPE
# define SHELL_TOKENTYPE
  enum shell_tokentype
  {
    shellERROR = 258,
    shellEOL = 259,
    shellSTRING = 260,
    shellNUMBER = 261,
    shellCOLL = 262,
    shellSUPP = 263,
    shellKEY = 264,
    shellUSER = 265,
    shellADMIN = 266,
    shellSERVER = 267,
    shellMASTER = 268,
    shellALL = 269,
    shellTO = 270,
    shellFROM = 271,
    shellAS = 272,
    shellFOR = 273,
    shellON = 274,
    shellINIT = 275,
    shellREMOVE = 276,
    shellPURGE = 277,
    shellCLEAN = 278,
    shellADD = 279,
    shellDEL = 280,
    shellNOTE = 281,
    shellLIST = 282,
    shellUPDATE = 283,
    shellUPGRADE = 284,
    shellUPGRADEP = 285,
    shellCOMMIT = 286,
    shellMAKE = 287,
    shellCHECK = 288,
    shellBIND = 289,
    shellUNBIND = 290,
    shellMOUNT = 291,
    shellUMOUNT = 292,
    shellUPLOAD = 293,
    shellFILE = 294,
    shellCATALOG = 295,
    shellRULES = 296,
    shellUPLOADP = 297,
    shellGET = 298,
    shellSU = 299,
    shellMOTD = 300,
    shellAUDIT = 301,
    shellSAVE = 302,
    shellEXTRACT = 303,
    shellNOTIFY = 304,
    shellQUICK = 305,
    shellSCAN = 306,
    shellTRIM = 307,
    shellSTATUS = 308,
    shellAROBASE = 309,
    shellCOLON = 310,
    shellMINUS = 311
  };
#endif
/* Tokens.  */
#define shellERROR 258
#define shellEOL 259
#define shellSTRING 260
#define shellNUMBER 261
#define shellCOLL 262
#define shellSUPP 263
#define shellKEY 264
#define shellUSER 265
#define shellADMIN 266
#define shellSERVER 267
#define shellMASTER 268
#define shellALL 269
#define shellTO 270
#define shellFROM 271
#define shellAS 272
#define shellFOR 273
#define shellON 274
#define shellINIT 275
#define shellREMOVE 276
#define shellPURGE 277
#define shellCLEAN 278
#define shellADD 279
#define shellDEL 280
#define shellNOTE 281
#define shellLIST 282
#define shellUPDATE 283
#define shellUPGRADE 284
#define shellUPGRADEP 285
#define shellCOMMIT 286
#define shellMAKE 287
#define shellCHECK 288
#define shellBIND 289
#define shellUNBIND 290
#define shellMOUNT 291
#define shellUMOUNT 292
#define shellUPLOAD 293
#define shellFILE 294
#define shellCATALOG 295
#define shellRULES 296
#define shellUPLOADP 297
#define shellGET 298
#define shellSU 299
#define shellMOTD 300
#define shellAUDIT 301
#define shellSAVE 302
#define shellEXTRACT 303
#define shellNOTIFY 304
#define shellQUICK 305
#define shellSCAN 306
#define shellTRIM 307
#define shellSTATUS 308
#define shellAROBASE 309
#define shellCOLON 310
#define shellMINUS 311

/* Value type.  */
#if ! defined SHELL_STYPE && ! defined SHELL_STYPE_IS_DECLARED

union SHELL_STYPE
{
#line 61 "parser/shellQuery.y" /* yacc.c:1909  */

  int         number;
  char        string[MAX_SIZE_STRING+1];
  Collection* coll;

#line 180 "parser/shellQuery.tab.h" /* yacc.c:1909  */
};

typedef union SHELL_STYPE SHELL_STYPE;
# define SHELL_STYPE_IS_TRIVIAL 1
# define SHELL_STYPE_IS_DECLARED 1
#endif



int shell_parse (yyscan_t yyscanner, Collection* coll, UploadParams* upParam);
/* "%code provides" blocks.  */
#line 26 "parser/shellQuery.y" /* yacc.c:1909  */

/*=======================================================================
 * Version: this file is generated by BISON using shellQuery.y
 * Project: Mediatex
 * Module : shell parser
 *
 * shell query parser.

 MediaTex is an Electronic Records Management System
 Copyright (C) 2014 2015 2016 2017 Nicolas Roche
   
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation, either version 3 of the License, or
 any later version.
   
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
   
 You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 =======================================================================*/

#define YYSTYPE SHELL_STYPE

#line 220 "parser/shellQuery.tab.h" /* yacc.c:1909  */

#endif /* !YY_SHELL_PARSER_SHELLQUERY_TAB_H_INCLUDED  */
